@@ -21,7 +21,7 @@ use Plack::Util::Accessor qw/ default_rate rules cache file _match greylist retr
 use Ref::Util             qw/ is_plain_arrayref /;
 use Time::Seconds         qw/ ONE_MINUTE /;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 sub prepare_app {
@@ -71,7 +71,7 @@ sub prepare_app {
     my @blocks;
 
     if ( my $greylist = $self->greylist ) {
-        push @blocks, ( $greylist->%* );
+        push @blocks, ( %{ $greylist } );
     }
 
     $self->rules( my $rules = {} );
@@ -85,7 +85,7 @@ sub prepare_app {
         my $rule  = $line->value;
         $rule = [ split /\s+/, $rule ] unless is_plain_arrayref($rule);
 
-        my ( $rate, $type ) = $rule->@*;
+        my ( $rate, $type ) = @{ $rule };
 
         $rate //= $codes{blacklist};
         $rate = $codes{$rate} if exists $codes{$rate};
@@ -167,7 +167,7 @@ Plack::Middleware::Greylist - throttle requests with different rates based on ne
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
